"use client"
/* */
import { ActionExecutionBatch } from './ActionExecutionBatch.mjs';

class ActionExecution {
  action;
  constructor(action) {
    this.action = action;
  }
  execute = (...args) => {
    const batches = this.getBatchedActions();
    const executeAllBatches = async () => {
      for (const batch of batches) {
        await batch.executeBatch(args);
      }
    };
    void executeAllBatches().catch((error) => console.error(error));
  };
  getBatchedActions = () => {
    let currentAction = this.action;
    const batches = [];
    let currentBatch = new ActionExecutionBatch(
      this.action
    );
    let skipCount = 0;
    while (currentAction) {
      const { action, break: $break, skip } = currentAction.actionProps;
      if (currentAction.needsConfirmation) {
        currentBatch.addAction(currentAction);
        break;
      }
      if (skip) {
        skipCount = skip === true ? 1 : skip;
        currentAction = currentAction.parentAction;
        continue;
      }
      if (skipCount > 0) {
        currentAction = currentAction.parentAction;
        skipCount--;
        continue;
      }
      if ($break) {
        break;
      }
      if (action) {
        currentBatch.addAction(currentAction);
      } else {
        batches.push(currentBatch);
        currentBatch = new ActionExecutionBatch(this.action);
        currentBatch.addAction(currentAction);
      }
      currentAction = currentAction.parentAction;
    }
    batches.push(currentBatch);
    return batches;
  };
}

export { ActionExecution };
//# sourceMappingURL=ActionExecution.mjs.map
