"use client"
/* */
import { jsx, jsxs } from 'react/jsx-runtime';
import * as Recharts from 'recharts';
import { Children, cloneElement, useRef, useState, useEffect } from 'react';
import { Area } from './components/Area/Area.mjs';
import { CartesianGrid } from '../CartesianGrid/CartesianGrid.mjs';
import clsx from 'clsx';
import styles from './AreaChart.module.scss.mjs';
import { Wrap } from '../Wrap/Wrap.mjs';

const AreaChart = (props) => {
  const {
    children,
    data,
    className,
    height,
    flexGrow,
    emptyView: EmptyView,
    ...rest
  } = props;
  const rootClassName = clsx(styles.areaChart, className);
  const areasWithoutDots = [];
  const areasWithDots = [];
  const otherChildren = [];
  const gridChildren = [];
  Children.forEach(children, (child, index) => {
    if (!child) return;
    const element = child;
    if (element.type === CartesianGrid) {
      gridChildren.push(element);
    } else if (element.type === Area) {
      areasWithoutDots.push(
        cloneElement(element, {
          onlyDots: false,
          key: `area-${index}`
        })
      );
      areasWithDots.push(
        cloneElement(element, {
          onlyDots: true,
          key: `area-dots-${index}`
        })
      );
    } else {
      otherChildren.push(element);
    }
  });
  const showEmptyView = (!data || data.length === 0) && EmptyView;
  const chartContainerRef = useRef(null);
  const [viewDimensions, setViewDimensions] = useState(null);
  useEffect(() => {
    if (showEmptyView) {
      const updateDimensions = () => {
        const svg = chartContainerRef.current?.querySelector(
          "svg"
        );
        if (!svg) return;
        const clip = svg.querySelector("clipPath rect");
        if (clip) {
          const x = parseFloat(clip.getAttribute("x") ?? "0");
          const y = parseFloat(clip.getAttribute("y") ?? "0");
          const width = parseFloat(clip.getAttribute("width") ?? "0");
          const height2 = parseFloat(clip.getAttribute("height") ?? "0");
          setViewDimensions({ x, y, width, height: height2 });
        }
      };
      updateDimensions();
      const container = chartContainerRef.current;
      const observer = new ResizeObserver(updateDimensions);
      if (container) observer.observe(container);
      return () => {
        observer.disconnect();
      };
    }
  }, []);
  return /* @__PURE__ */ jsx(Wrap, { if: height, children: /* @__PURE__ */ jsx(
    "div",
    {
      style: { height, flex: flexGrow ? 1 : void 0 },
      ref: chartContainerRef,
      children: /* @__PURE__ */ jsx(Recharts.ResponsiveContainer, { children: /* @__PURE__ */ jsxs(Recharts.AreaChart, { data, className: rootClassName, ...rest, children: [
        !showEmptyView && gridChildren,
        areasWithoutDots,
        otherChildren,
        areasWithDots,
        showEmptyView && viewDimensions && /* @__PURE__ */ jsx("foreignObject", { ...viewDimensions, children: /* @__PURE__ */ jsx("div", { className: styles.emptyViewContainer, children: /* @__PURE__ */ jsx(EmptyView, { data }) }) })
      ] }) })
    }
  ) });
};

export { AreaChart, AreaChart as default };
//# sourceMappingURL=AreaChart.mjs.map
