"use client"
/* */
import { jsx } from 'react/jsx-runtime';
import { useRef } from 'react';
import '../../lib/propsContext/propsContext.mjs';
import '../../lib/viewComponentContext/viewComponentContext.mjs';
import { PropsContextProvider } from '../../lib/propsContext/PropsContextProvider.mjs';
import * as Aria from 'react-aria-components';
import 'mobx';
import { useOverlayController } from '../../lib/controller/overlay/useOverlayController.mjs';
import { flowComponent } from '../../lib/componentFactory/flowComponent.mjs';
import { useLocalizedStringFormatter, useFocusWithin, UNSAFE_PortalProvider } from 'react-aria';
import styles from './Autocomplete.module.scss.mjs';
import locales from '../../../../_virtual/_.locale.json@48bdcfec6dd32df5dc9f6fa222d33240.mjs';
import { Text } from '../Text/Text.mjs';

const Autocomplete = flowComponent("Autocomplete", (props) => {
  const { children, ...rest } = props;
  const stringFormatter = useLocalizedStringFormatter(locales);
  const { contains } = Aria.useFilter({ sensitivity: "base" });
  const triggerRef = useRef(null);
  const container = useRef(null);
  const controller = useOverlayController("ContextMenu", {
    reuseControllerFromContext: false
  });
  const focusWithin = useFocusWithin({
    onBlurWithin: controller.close
  });
  const menuIsOpen = controller.useIsOpen();
  const inputProps = {
    onKeyDown: (e) => {
      if (e.key === "Enter" && menuIsOpen) {
        e.preventDefault();
      }
    },
    ref: triggerRef
  };
  const propsContext = {
    ContextMenu: {
      placement: "bottom start",
      controller,
      isNonModal: true,
      renderEmptyState: () => /* @__PURE__ */ jsx(Text, { className: styles.empty, children: stringFormatter.format("autocomplete.empty") }),
      onAction: (key) => {
        const input = triggerRef.current;
        if (input) {
          const nativeInputValueSetter = Object.getOwnPropertyDescriptor(
            Object.getPrototypeOf(input),
            "value"
          )?.set;
          nativeInputValueSetter?.call(input, String(key));
          const event = new Event("change", { bubbles: true });
          input.dispatchEvent(event);
        }
      },
      triggerRef
    },
    SearchField: inputProps,
    TextField: inputProps
  };
  const handleOnInputChange = (value) => {
    if (!value) {
      controller.close();
    } else if (!menuIsOpen) {
      controller.open();
    }
  };
  return /* @__PURE__ */ jsx(
    PropsContextProvider,
    {
      props: propsContext,
      mergeInParentContext: true,
      dependencies: [menuIsOpen, controller],
      children: /* @__PURE__ */ jsx("div", { ...focusWithin.focusWithinProps, ref: container, children: /* @__PURE__ */ jsx(UNSAFE_PortalProvider, { getContainer: () => container.current, children: /* @__PURE__ */ jsx(
        Aria.Autocomplete,
        {
          onInputChange: handleOnInputChange,
          filter: contains,
          ...rest,
          children
        }
      ) }) })
    }
  );
});

export { Autocomplete, Autocomplete as default };
//# sourceMappingURL=Autocomplete.mjs.map
