"use client"
/* */
import { jsx, jsxs } from 'react/jsx-runtime';
import * as Aria from 'react-aria-components';
import clsx from 'clsx';
import styles from './DonutChart.module.scss.mjs';
import { DonutChartValue } from './components/DonutChartValue.mjs';
import { Donut } from './components/Donut.mjs';
import { Wrap } from '../Wrap/Wrap.mjs';
import { DonutChartLegend } from './components/DonutChartLegend.mjs';

const DonutChart = (props) => {
  const {
    size = "m",
    status = "info",
    className,
    value,
    segments,
    maxValue,
    formatOptions,
    showLegend = true,
    legendPosition = "right",
    children,
    ...rest
  } = props;
  const rootClassName = clsx(
    styles.donutChart,
    size === "l" && styles["size-l"],
    styles[status],
    className
  );
  const segmentsTotalValue = segments ? segments.map((s) => s.value).reduce((a, b) => a + b, 0) : void 0;
  return /* @__PURE__ */ jsx(Wrap, { if: showLegend && segments, children: /* @__PURE__ */ jsxs("div", { className: clsx(styles.donutChartContainer, styles[legendPosition]), children: [
    /* @__PURE__ */ jsxs(
      Aria.ProgressBar,
      {
        className: rootClassName,
        value: segmentsTotalValue ?? value,
        ...rest,
        children: [
          /* @__PURE__ */ jsx(
            Donut,
            {
              value: segmentsTotalValue ?? value,
              segments,
              size,
              maxValue
            }
          ),
          /* @__PURE__ */ jsx(
            DonutChartValue,
            {
              value: segmentsTotalValue ?? value,
              formatOptions,
              children
            }
          )
        ]
      }
    ),
    showLegend && segments && /* @__PURE__ */ jsx(
      DonutChartLegend,
      {
        showLegend,
        segments,
        formatOptions
      }
    )
  ] }) });
};

export { DonutChart, DonutChart as default };
//# sourceMappingURL=DonutChart.mjs.map
