"use client"
/* */
import { jsx } from 'react/jsx-runtime';
import { CodeBlock } from '../CodeBlock/CodeBlock.mjs';
import { Heading } from '../Heading/Heading.mjs';
import { InlineCode } from '../InlineCode/InlineCode.mjs';
import { Link } from '../Link/Link.mjs';
import { Separator } from '../Separator/Separator.mjs';
import { Text } from '../Text/Text.mjs';
import React, { isValidElement, Children } from 'react';
import ReactMarkdown from 'react-markdown';
import styles from './Markdown.module.scss.mjs';
import { isRemoteTextRenderProps } from '../../lib/react/remote.mjs';

const Markdown = (props) => {
  const { children, color = "default", ...rest } = props;
  const headingAndLinkColor = color === "default" ? "primary" : color;
  const textColor = color === "default" ? void 0 : color;
  const components = {
    a: (props2) => /* @__PURE__ */ jsx(Link, { target: "_blank", color: headingAndLinkColor, href: props2.href, children: props2.children }),
    p: (props2) => /* @__PURE__ */ jsx(Text, { elementType: "p", color: textColor, children: props2.children }),
    code: (props2) => /* @__PURE__ */ jsx(InlineCode, { color, children: props2.children }),
    h1: (props2) => /* @__PURE__ */ jsx(Heading, { level: 1, color: headingAndLinkColor, children: props2.children }),
    h2: (props2) => /* @__PURE__ */ jsx(Heading, { level: 2, color: headingAndLinkColor, children: props2.children }),
    h3: (props2) => /* @__PURE__ */ jsx(Heading, { level: 3, color: headingAndLinkColor, children: props2.children }),
    h4: (props2) => /* @__PURE__ */ jsx(Heading, { level: 4, color: headingAndLinkColor, children: props2.children }),
    h5: (props2) => /* @__PURE__ */ jsx(Heading, { level: 5, color: headingAndLinkColor, children: props2.children }),
    h6: (props2) => /* @__PURE__ */ jsx(Heading, { level: 6, color: headingAndLinkColor, children: props2.children }),
    hr: () => /* @__PURE__ */ jsx(Separator, {}),
    pre: (props2) => {
      const preElementContent = Children.toArray(props2.children)[0];
      return /* @__PURE__ */ jsx(
        CodeBlock,
        {
          copyable: false,
          color,
          language: isValidElement(preElementContent) && preElementContent.props.className ? preElementContent.props.className.replace("language-", "") : void 0,
          code: String(
            isValidElement(preElementContent) ? preElementContent.props.children : preElementContent
          )
        }
      );
    },
    ul: (props2) => /* @__PURE__ */ jsx(Text, { color: textColor, children: /* @__PURE__ */ jsx("ul", { children: props2.children }) }),
    ol: (props2) => /* @__PURE__ */ jsx(Text, { color: textColor, children: /* @__PURE__ */ jsx("ol", { children: props2.children }) }),
    blockquote: (props2) => /* @__PURE__ */ jsx(Text, { color: textColor, children: /* @__PURE__ */ jsx("blockquote", { children: props2.children }) })
  };
  const firstChild = React.Children.toArray(children)[0];
  const textContent = typeof firstChild === "string" ? firstChild : isValidElement(firstChild) && isRemoteTextRenderProps(firstChild.props) ? firstChild.props.remote.data : "";
  return /* @__PURE__ */ jsx("div", { className: styles.markdown, ...rest, children: /* @__PURE__ */ jsx(ReactMarkdown, { components, children: textContent }) });
};

export { Markdown, Markdown as default };
//# sourceMappingURL=Markdown.mjs.map
