"use client"
/* */
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { useState, useDeferredValue, useEffect, startTransition } from 'react';
import { ClearPropsContext } from '../ClearPropsContext/ClearPropsContext.mjs';
import '../../lib/propsContext/propsContext.mjs';
import { dynamic } from '../../lib/propsContext/dynamicProps/dynamic.mjs';
import { PropsContextProvider } from '../../lib/propsContext/PropsContextProvider.mjs';
import { flowComponent } from '../../lib/componentFactory/flowComponent.mjs';
import styles from './PasswordCreationField.module.scss.mjs';
import * as Aria from 'react-aria-components';
import { FieldErrorContext } from 'react-aria-components';
import formFieldStyles from '../FormField/FormField.module.scss.mjs';
import clsx from 'clsx';
import { TunnelProvider, TunnelExit } from '@mittwald/react-tunnel';
import '../Action/Action.mjs';
import { getStateFromLatestPolicyValidationResult } from './lib/getStateFromLatestPolicyValidationResult.mjs';
import locales from '../../../../_virtual/_.locale.json@95341064edeb0e38b66d786dbd62955c.mjs';
import { generateValidationTranslation } from './lib/generateValidationTranslation.mjs';
import { FieldError } from '../FieldError/FieldError.mjs';
import { FieldDescription } from '../FieldDescription/FieldDescription.mjs';
import { ComplexityIndicator } from './components/ComplexityIndicator/ComplexityIndicator.mjs';
import '@mittwald/password-tools-js/policy';
import '@mittwald/password-tools-js/rules';
import { generatePassword } from './worker/generatePassword.mjs';
import { TogglePasswordVisibilityButton } from './components/TogglePasswordVisibilityButton/TogglePasswordVisibilityButton.mjs';
import { defaultPasswordCreationPolicy } from './defaultPasswordCreationPolicy.mjs';
import { Wrap } from '../Wrap/Wrap.mjs';
import { ReactAriaControlledValueFix } from '../../lib/react/ReactAriaControlledValueFix.mjs';
import { ValidationResultButton } from './components/ValidationResultButton/ValidationResultButton.mjs';
import { PasswordGenerateButton } from './components/PasswordGenerateButton/PasswordGenerateButton.mjs';
import { useLocalizedContextStringFormatter } from '../TranslationProvider/useLocalizedContextStringFormatter.mjs';
import { isPromise } from 'remeda';

const PasswordCreationField = flowComponent(
  "PasswordCreationField",
  (props) => {
    const {
      children,
      className,
      ref,
      isDisabled,
      onChange: onChangeFromProps,
      onValidationResult,
      isInvalid: invalidFromProps,
      validationPolicy = defaultPasswordCreationPolicy,
      isRequired,
      value: valueFromProps,
      defaultValue,
      ...rest
    } = props;
    const isControlled = typeof valueFromProps !== "undefined";
    const hasDefaultValue = typeof defaultValue !== "undefined";
    const [internalValue, setInternalValue] = useState(
      hasDefaultValue ? defaultValue : ""
    );
    const value = isControlled ? valueFromProps : internalValue;
    const deferredValue = useDeferredValue(value);
    const onChangeHandler = (value2) => {
      if (onChangeFromProps) {
        onChangeFromProps(value2);
      }
      if (!isControlled) {
        setInternalValue(() => value2);
      }
    };
    const translate = useLocalizedContextStringFormatter(locales);
    const [isPasswordRevealed, setIsPasswordRevealed] = useState(false);
    const [isLoading, setIsLoading] = useState(false);
    const initialPolicyValidationState = {
      initialValidate: true,
      isValid: false,
      complexity: {
        min: validationPolicy.minComplexity,
        actual: 4,
        warning: null
      },
      ruleResults: []
    };
    const [policyValidationResult, setPolicyValidationResult] = useState(
      initialPolicyValidationState
    );
    const stateFromValidationResult = getStateFromLatestPolicyValidationResult(
      policyValidationResult
    );
    let latestValidationErrorText = void 0;
    if (stateFromValidationResult) {
      const [translationKey, translationValues] = generateValidationTranslation(
        stateFromValidationResult
      );
      latestValidationErrorText = translate.format(
        translationKey,
        translationValues
      );
    }
    const isEmptyValue = !value;
    const isValidFromValidationResult = !isEmptyValue && stateFromValidationResult?.isValid;
    const isInvalidFromValidationResult = !isEmptyValue && !stateFromValidationResult?.isValid;
    const isInvalid = invalidFromProps || isInvalidFromValidationResult;
    const setOptimisticPolicyValidationResult = (state = {}) => {
      setPolicyValidationResult(() => ({
        ...initialPolicyValidationState,
        ...state,
        isValid: state.isValid ?? true
      }));
    };
    useEffect(() => {
      startTransition(async () => {
        const validationResult = validationPolicy.validate(deferredValue);
        if (!isPromise(validationResult.isValid)) {
          const isValid = validationResult.isValid;
          setIsLoading(() => false);
          setPolicyValidationResult((old) => {
            if (!old.initialValidate) {
              onValidationResult?.({ password: deferredValue, isValid });
            }
            return {
              initialValidate: false,
              isValid,
              ruleResults: validationResult.ruleResults,
              complexity: validationResult.complexity
            };
          });
          return;
        }
        const nonPromiseValidationsInvalid = validationResult.ruleResults.filter((r) => !(r instanceof Promise)).some((r) => !r.isValid);
        if (!isEmptyValue) {
          setIsLoading(() => true);
        }
        if (!nonPromiseValidationsInvalid) {
          setOptimisticPolicyValidationResult();
        }
        void Promise.all([
          Promise.resolve(deferredValue),
          ...validationResult.ruleResults.map(async (r) => {
            return r;
          })
        ]).then(([resolvedValue, ...validationResults]) => {
          startTransition(() => {
            const isValid = !validationResults.some((r) => !r.isValid);
            setIsLoading(() => false);
            setPolicyValidationResult((old) => {
              if (!old.initialValidate) {
                onValidationResult?.({ password: resolvedValue, isValid });
              }
              return {
                ...old,
                isValid,
                ruleResults: validationResults
              };
            });
          });
        });
      });
    }, [deferredValue]);
    const onPasswordGenerateHandler = async () => {
      const generatedPassword = await generatePassword(validationPolicy);
      setOptimisticPolicyValidationResult();
      setIsPasswordRevealed(true);
      onChangeHandler(generatedPassword);
    };
    const onPasswordPasteHandler = (event) => {
      const pastedValue = event.clipboardData.getData("text");
      if (pastedValue !== value) {
        setOptimisticPolicyValidationResult({
          isValid: "indeterminate"
        });
        onChangeHandler(pastedValue);
      }
    };
    const togglePasswordVisibilityHandler = () => {
      setIsPasswordRevealed((old) => !old);
    };
    const propsContext = {
      Button: {
        tunnelId: "button",
        size: "m",
        variant: "plain",
        color: "secondary",
        isDisabled,
        className: styles.button
      },
      CopyButton: {
        tunnelId: "button",
        size: "m",
        variant: "plain",
        color: "secondary",
        isDisabled,
        className: styles.button,
        text: value
      },
      Label: {
        className: formFieldStyles.label,
        tunnelId: "label",
        optional: !isRequired,
        isDisabled,
        children: dynamic((localProps) => {
          return /* @__PURE__ */ jsxs(Fragment, { children: [
            localProps.children,
            /* @__PURE__ */ jsx(
              PasswordGenerateButton,
              {
                isDisabled,
                onGeneratePasswordAction: onPasswordGenerateHandler
              }
            ),
            /* @__PURE__ */ jsx(
              ValidationResultButton,
              {
                isEmptyValue,
                isDisabled,
                policyValidationResult
              }
            )
          ] });
        })
      },
      FieldDescription: {
        className: formFieldStyles.fieldDescription
      },
      FieldError: {
        className: formFieldStyles.customFieldError,
        children: dynamic(() => {
          if (latestValidationErrorText) {
            return latestValidationErrorText;
          }
        })
      }
    };
    return /* @__PURE__ */ jsx(ClearPropsContext, { children: /* @__PURE__ */ jsx(TunnelProvider, { children: /* @__PURE__ */ jsxs(
      Aria.TextField,
      {
        ...rest,
        value,
        type: isPasswordRevealed ? "text" : "password",
        onChange: onChangeHandler,
        onPaste: onPasswordPasteHandler,
        className: clsx(className, formFieldStyles.formField),
        isDisabled,
        isInvalid,
        isRequired,
        children: [
          /* @__PURE__ */ jsx(TunnelExit, { id: "label" }),
          /* @__PURE__ */ jsxs(
            Aria.Group,
            {
              isDisabled,
              className: clsx(styles.inputGroup),
              children: [
                /* @__PURE__ */ jsx(
                  ReactAriaControlledValueFix,
                  {
                    inputContext: Aria.InputContext,
                    props: { ...props, value },
                    children: /* @__PURE__ */ jsx(Aria.Input, { ref, className: styles.input })
                  }
                ),
                /* @__PURE__ */ jsxs(Aria.Group, { className: styles.buttonContainer, children: [
                  /* @__PURE__ */ jsx(
                    TogglePasswordVisibilityButton,
                    {
                      className: styles.button,
                      isVisible: isPasswordRevealed,
                      isDisabled,
                      onPress: togglePasswordVisibilityHandler
                    }
                  ),
                  /* @__PURE__ */ jsx(TunnelExit, { id: "button" })
                ] }),
                /* @__PURE__ */ jsx(
                  ComplexityIndicator,
                  {
                    isEmptyValue,
                    isLoading,
                    policyValidationResult
                  }
                )
              ]
            }
          ),
          /* @__PURE__ */ jsxs(PropsContextProvider, { props: propsContext, children: [
            isValidFromValidationResult && /* @__PURE__ */ jsx(FieldDescription, { children: latestValidationErrorText }),
            isInvalidFromValidationResult && policyValidationResult.isValid !== "indeterminate" && /* @__PURE__ */ jsx(FieldError, { children: latestValidationErrorText }),
            /* @__PURE__ */ jsx(Wrap, { if: isInvalidFromValidationResult, children: /* @__PURE__ */ jsx(
              FieldErrorContext.Provider,
              {
                value: {
                  isInvalid: false,
                  validationErrors: [],
                  validationDetails: {
                    customError: false,
                    valid: true,
                    typeMismatch: false,
                    stepMismatch: false,
                    valueMissing: false,
                    tooShort: false,
                    tooLong: false,
                    rangeUnderflow: false,
                    patternMismatch: false,
                    badInput: false,
                    rangeOverflow: false
                  }
                },
                children
              }
            ) })
          ] })
        ]
      }
    ) }) });
  }
);

export { PasswordCreationField, PasswordCreationField as default };
//# sourceMappingURL=PasswordCreationField.mjs.map
