"use client"
/* */
import { jsx, jsxs } from 'react/jsx-runtime';
import * as Aria from 'react-aria-components';
import '../../lib/propsContext/propsContext.mjs';
import 'react';
import '../../lib/viewComponentContext/viewComponentContext.mjs';
import { PropsContextProvider } from '../../lib/propsContext/PropsContextProvider.mjs';
import formFieldStyles from '../FormField/FormField.module.scss.mjs';
import { FieldError } from '../FieldError/FieldError.mjs';
import styles from './Select.module.scss.mjs';
import clsx from 'clsx';
import '@tabler/icons-react';
import '../Icon/Icon.mjs';
import { IconChevronDown } from '../Icon/components/icons/IconChevronDown.mjs';
import { flowComponent } from '../../lib/componentFactory/flowComponent.mjs';
import { Options } from '../Options/Options.mjs';
import { TunnelProvider, TunnelExit } from '@mittwald/react-tunnel';
import 'mobx';
import { useOverlayController } from '../../lib/controller/overlay/useOverlayController.mjs';

const Select = flowComponent("Select", (props) => {
  const {
    children,
    className,
    onChange = () => {
    },
    onSelectionChange = () => {
    },
    controller: controllerFromProps,
    ref,
    ...rest
  } = props;
  const rootClassName = clsx(
    styles.select,
    formFieldStyles.formField,
    className
  );
  const propsContext = {
    Label: {
      className: formFieldStyles.label,
      optional: !props.isRequired
    },
    FieldDescription: {
      className: formFieldStyles.fieldDescription
    },
    FieldError: {
      className: formFieldStyles.customFieldError
    },
    Option: {
      tunnelId: "options"
    }
  };
  const handleOnSelectionChange = (id) => {
    onChange(String(id));
    onSelectionChange(id);
  };
  const controllerFromContext = useOverlayController("Select", {
    reuseControllerFromContext: true
  });
  const controller = controllerFromProps ?? controllerFromContext;
  const isOpen = controller.useIsOpen();
  return /* @__PURE__ */ jsx(
    Aria.Select,
    {
      ...rest,
      className: rootClassName,
      ref,
      onSelectionChange: handleOnSelectionChange,
      onOpenChange: (isOpen2) => controller.setOpen(isOpen2),
      isOpen,
      children: /* @__PURE__ */ jsx(PropsContextProvider, { props: propsContext, children: /* @__PURE__ */ jsxs(TunnelProvider, { children: [
        /* @__PURE__ */ jsxs(Aria.Button, { className: styles.toggle, children: [
          /* @__PURE__ */ jsx(Aria.SelectValue, {}),
          /* @__PURE__ */ jsx(IconChevronDown, {})
        ] }),
        children,
        /* @__PURE__ */ jsx(Options, { controller, children: /* @__PURE__ */ jsx(TunnelExit, { id: "options" }) }),
        /* @__PURE__ */ jsx(FieldError, { className: formFieldStyles.fieldError })
      ] }) })
    }
  );
});

export { Select, Select as default };
//# sourceMappingURL=Select.mjs.map
