"use client"
/* */
import { ObservableMap, makeAutoObservable, toJS } from 'mobx';
import { mobxMapToObject } from '../../../lib/mobx/mobxMapToObject.mjs';
import { mapValues } from 'remeda';

class ComponentSettings {
  settings;
  constructor(settings = new ObservableMap()) {
    this.settings = settings;
    makeAutoObservable(this);
  }
  set(settingKey, schema, value) {
    this.settings.set(settingKey, schema.parse(toJS(value)));
  }
  get(settingKey, schema) {
    return schema.parse(this.settings.get(settingKey));
  }
  clear(settingKey) {
    this.settings.delete(settingKey);
  }
  get asJson() {
    return mapValues(mobxMapToObject(this.settings), (v) => JSON.stringify(v));
  }
  static fromJson(json) {
    return new ComponentSettings(
      new ObservableMap(
        mapValues(json, (v) => typeof v === "string" ? JSON.parse(v) : v)
      )
    );
  }
}

export { ComponentSettings };
//# sourceMappingURL=ComponentSettings.mjs.map
