"use client"
/* */
import { ObservableMap, makeAutoObservable } from 'mobx';
import { ComponentSettings } from './ComponentSettings.mjs';
import { mapValues } from 'remeda';
import { mobxMapToObject } from '../../../lib/mobx/mobxMapToObject.mjs';

class SettingsStore {
  componentSettings;
  constructor(settings = new ObservableMap()) {
    this.componentSettings = settings;
    makeAutoObservable(this);
  }
  set(componentName, settingKey, schema, value) {
    const settings = this.componentSettings.get(componentName) ?? new ComponentSettings();
    settings.set(settingKey, schema, value);
    this.componentSettings.set(componentName, settings);
  }
  get(componentName, settingKey, schema) {
    const settings = this.componentSettings.get(componentName) ?? new ComponentSettings();
    return settings.get(settingKey, schema);
  }
  clear(componentName, settingKey) {
    this.componentSettings.get(componentName)?.clear(settingKey);
  }
  get asJson() {
    return mapValues(mobxMapToObject(this.componentSettings), (v) => v.asJson);
  }
  static fromJson(json) {
    const settings = mapValues(json, (v) => ComponentSettings.fromJson(v));
    return new SettingsStore(new ObservableMap(settings));
  }
}

export { SettingsStore };
//# sourceMappingURL=SettingsStore.mjs.map
