"use client"
/* */
import { jsx } from 'react/jsx-runtime';
import { useState, useEffect } from 'react';
import { ActionStateContext } from '../../../../components/Action/ActionStateContext.mjs';
import { useFormContext } from '../context/formContext.mjs';

const ActionStateContextWrapper = (props) => {
  const { children, isAsyncSubmit } = props;
  const form = useFormContext().form;
  const [submitErrors, setSubmitErrors] = useState(void 0);
  const [hasSucceeded, setHasSucceeded] = useState(false);
  const [isStarted, setIsStarted] = useState(false);
  useEffect(() => {
    const { isSubmitted, isSubmitting, isSubmitSuccessful, errors } = form.formState;
    setSubmitErrors(
      isSubmitted && errors && Object.entries(errors).length > 0 ? errors : void 0
    );
    setHasSucceeded(isSubmitted && isSubmitSuccessful);
    setIsStarted(isSubmitting && isAsyncSubmit.current);
  }, [
    form.formState.isSubmitted,
    form.formState.isSubmitting,
    form.formState.isSubmitSuccessful,
    form.formState.errors,
    isAsyncSubmit.current
  ]);
  return /* @__PURE__ */ jsx(
    ActionStateContext,
    {
      isStarted,
      hasFailedWithError: submitErrors,
      hasSucceeded,
      children
    }
  );
};
const SubmitButtonStateProvider = (props) => {
  const { children, isAsyncSubmit } = props;
  return /* @__PURE__ */ jsx(ActionStateContextWrapper, { isAsyncSubmit, children });
};

export { SubmitButtonStateProvider };
//# sourceMappingURL=SubmitButtonStateProvider.mjs.map
