"use client"
/* */
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { useFormContext } from '../context/formContext.mjs';
import '../../../../lib/propsContext/propsContext.mjs';
import 'react';
import '../../../../lib/viewComponentContext/viewComponentContext.mjs';
import { dynamic } from '../../../../lib/propsContext/dynamicProps/dynamic.mjs';
import { PropsContextProvider } from '../../../../lib/propsContext/PropsContextProvider.mjs';
import { useController } from 'react-hook-form';
import FieldErrorView from '../../../../views/FieldErrorView.mjs';

function Field(props) {
  const { children, name, defaultValue, ...rest } = props;
  const controller = useController(props);
  const formContext = useFormContext();
  const value = controller.field.value;
  const fieldProps = {
    ...controller.field,
    name,
    form: formContext.id,
    isRequired: !!rest.rules?.required,
    validationBehavior: "aria",
    defaultValue,
    isInvalid: controller.fieldState.invalid,
    children: dynamic((p) => {
      if (controller.fieldState.invalid) {
        return /* @__PURE__ */ jsxs(Fragment, { children: [
          p.children,
          /* @__PURE__ */ jsx(FieldErrorView, { children: controller.fieldState.error?.message })
        ] });
      }
      return p.children;
    })
  };
  const { value: ignoredValue, ...fieldPropsWithoutValue } = fieldProps;
  const propsContext = {
    SearchField: fieldProps,
    TextField: fieldProps,
    TextArea: fieldProps,
    Checkbox: {
      ...fieldProps,
      isSelected: value
    },
    CheckboxGroup: fieldProps,
    CheckboxButton: {
      ...fieldProps,
      isSelected: value
    },
    FileField: fieldProps,
    FileDropZone: fieldProps,
    NumberField: fieldProps,
    RadioGroup: fieldProps,
    Switch: {
      ...fieldProps,
      isSelected: value
    },
    Slider: fieldProps,
    PasswordCreationField: fieldProps,
    DatePicker: fieldProps,
    DateRangePicker: fieldProps,
    TimeField: fieldProps,
    SegmentedControl: fieldProps,
    Select: {
      ...fieldProps,
      selectedKey: value
    },
    ComboBox: {
      ...fieldPropsWithoutValue,
      selectedKey: value
    }
  };
  return /* @__PURE__ */ jsx(
    PropsContextProvider,
    {
      props: propsContext,
      dependencies: [controller.fieldState, controller.field, value],
      children
    }
  );
}
const typedField = (ignoredForm) => Field;

export { Field, Field as default, typedField };
//# sourceMappingURL=Field.mjs.map
