"use client"
/* */
import { jsx, jsxs } from 'react/jsx-runtime';
import { SubmitButtonStateProvider } from '../ActionGroupWrapper/SubmitButtonStateProvider.mjs';
import { FormContextProvider } from '../context/formContext.mjs';
import { useId, useRef, useMemo } from 'react';
import { FormProvider } from 'react-hook-form';
import { AfterFormSubmitEffect } from '../AfterFormSubmitEffect/AfterFormSubmitEffect.mjs';

const DefaultFormComponent = (p) => /* @__PURE__ */ jsx("form", { ...p });
function Form(props) {
  const {
    form,
    children,
    onSubmit,
    formComponent: FormView = DefaultFormComponent,
    ...formProps
  } = props;
  const formId = useId();
  const isAsyncSubmit = useRef(false);
  const submitHandlerResultRef = useRef(null);
  const FormViewComponent = useMemo(() => FormView, [formId]);
  const handleOnSubmit = (e) => {
    const { isSubmitting, isValidating } = form.control._formState;
    const formEvent = e && "nativeEvent" in e ? e : void 0;
    formEvent?.stopPropagation();
    if (isSubmitting || isValidating) {
      formEvent?.preventDefault();
      return;
    }
    submitHandlerResultRef.current = void 0;
    form.handleSubmit((values) => {
      const result = onSubmit(values, formEvent);
      isAsyncSubmit.current = result instanceof Promise;
      submitHandlerResultRef.current = result;
      return result;
    })(formEvent);
  };
  return /* @__PURE__ */ jsx(FormProvider, { ...form, children: /* @__PURE__ */ jsxs(FormContextProvider, { value: { form, id: formId }, children: [
    /* @__PURE__ */ jsx(SubmitButtonStateProvider, { isAsyncSubmit, children: /* @__PURE__ */ jsx(
      FormViewComponent,
      {
        ...formProps,
        id: formId,
        onSubmit: handleOnSubmit,
        children
      }
    ) }),
    /* @__PURE__ */ jsx(
      AfterFormSubmitEffect,
      {
        submitHandlerResultRef
      }
    )
  ] }) });
}

export { Form, Form as default };
//# sourceMappingURL=Form.mjs.map
