"use client"
/* */
import { jsx } from 'react/jsx-runtime';
import * as Aria from 'react-aria-components';
import { Children, isValidElement, useLayoutEffect } from 'react';

const ReactAriaControlledValueFix = (props) => {
  const { inputContext: context, children } = props;
  const child = Children.only(children);
  if (!isValidElement(child)) {
    throw new Error("Expected valid element");
  }
  const { ref, ...inputProps } = child.props;
  const [contextProps, contextRef] = Aria.useContextProps(
    inputProps,
    ref,
    context
  );
  useLayoutEffect(() => {
    const element = contextRef.current;
    if (element instanceof HTMLInputElement || element instanceof HTMLTextAreaElement) {
      const newValue = String(contextProps.value ?? "");
      try {
        const nativeInputValueSetter = Object.getOwnPropertyDescriptor(
          Object.getPrototypeOf(element),
          "value"
        )?.set;
        nativeInputValueSetter?.call(element, newValue);
      } catch (ignoredError) {
        element.value = newValue;
      }
    }
  }, [contextProps.value]);
  const uncontrolledContextProps = {
    ...contextProps,
    value: void 0,
    ref: contextRef
  };
  return /* @__PURE__ */ jsx(Aria.Provider, { values: [[context, uncontrolledContextProps]], children: child });
};

export { ReactAriaControlledValueFix };
//# sourceMappingURL=ReactAriaControlledValueFix.mjs.map
