"use client"
/* */
import { Duration, DateTime } from 'luxon';

class Timer {
  duration = Duration.fromDurationLike(0);
  onDone;
  startedAt;
  pausedAt;
  runningTimeoutId;
  start(duration, onDone) {
    if (this.startedAt) {
      throw new Error("Timer already started");
    }
    this.duration = Duration.fromDurationLike(duration);
    this.onDone = onDone;
    this.startTimeout(this.duration);
  }
  restart() {
    this.stop();
    this.startTimeout(this.duration);
  }
  pause() {
    this.clearTimeout();
    const now = DateTime.now();
    this.pausedAt = now;
    if (!this.startedAt) {
      this.startedAt = now;
    }
  }
  resume() {
    if (!this.startedAt) {
      throw new Error("Timer not paused");
    } else if (this.pausedAt) {
      const elapsed = this.pausedAt.diff(this.startedAt);
      const remainingDuration = this.duration.minus(elapsed);
      this.startTimeout(remainingDuration);
    }
  }
  stop() {
    this.clearTimeout();
    this.startedAt = void 0;
    this.pausedAt = void 0;
  }
  get state() {
    return this.pausedAt ? "paused" : this.startedAt ? "running" : "idle";
  }
  clearTimeout() {
    if (this.runningTimeoutId) {
      window.clearTimeout(this.runningTimeoutId);
    }
    this.runningTimeoutId = void 0;
  }
  startTimeout(duration) {
    this.startedAt = DateTime.now();
    this.pausedAt = void 0;
    this.runningTimeoutId = window.setTimeout(() => {
      this.stop();
      if (this.onDone) {
        this.onDone();
      }
    }, duration.toMillis());
  }
}

export { Timer, Timer as default };
//# sourceMappingURL=Timer.mjs.map
