import { PropsWithChildren, default as React } from 'react';
import { PropsWithClassName, PropsWithElementType } from '../../lib/types/props';
import { FlowComponentProps } from '../../lib/componentFactory/flowComponent';
type GapSize = "s" | "m" | "l" | "xl";
export interface ColumnLayoutProps<T extends keyof HTMLElementTagNameMap = "div" | "ul"> extends PropsWithChildren, PropsWithElementType<T>, PropsWithClassName, FlowComponentProps<HTMLElementTagNameMap[T]> {
    /** Column layout for container size s. */
    s?: (number | null)[];
    /** Column layout for container size m. */
    m?: (number | null)[];
    /** Column layout for container size l. */
    l?: (number | null)[];
    /**
     * Size of the row and column gap between the content blocks inside the column
     * layout.
     *
     * @default "m"
     */
    gap?: GapSize;
    /** Size of the row gap between the content blocks inside the column layout. */
    rowGap?: GapSize;
    /** Size of the column gap between the content blocks inside the column layout. */
    columnGap?: GapSize;
}
/**
 * @flr-generate all
 * @flr-clear-props-context
 */
export declare const ColumnLayout: React.FunctionComponent<ColumnLayoutProps<"div" | "ul"> & React.RefAttributes<HTMLDivElement | HTMLUListElement>>;
export default ColumnLayout;
//# sourceMappingURL=ColumnLayout.d.ts.map