import { ItemCollection } from './item/ItemCollection';
import { BatchesController } from './pagination/BatchesController';
import { Filter } from './filter/Filter';
import { Sorting } from './sorting/Sorting';
import { default as ReactTable } from './ReactTable';
import { GetItemId, ItemActionFn, ListShape, ListSupportedComponentProps, ListViewMode } from './types';
import { IncrementalLoader } from './loading/IncrementalLoader';
import { Search } from './search/Search';
import { ItemView } from './item/ItemView';
import { Table } from './table/Table';
import { default as z } from 'zod';
export declare class List<T> {
    static readonly viewModeSettingsStorageSchema: z.ZodOptional<z.ZodEnum<["list", "table", "tiles"]>>;
    readonly filters: Filter<T, never, never>[];
    readonly itemView?: ItemView<T>;
    readonly table?: Table<T>;
    readonly search?: Search<T>;
    readonly sorting: Sorting<T>[];
    readonly items: ItemCollection<T>;
    readonly reactTable: ReactTable<T>;
    readonly batches: BatchesController<T>;
    readonly loader: IncrementalLoader<T>;
    readonly onAction?: ItemActionFn<T>;
    readonly accordion: boolean;
    readonly getItemId?: GetItemId<T>;
    readonly componentProps: ListSupportedComponentProps;
    viewMode: ListViewMode;
    readonly setViewMode: (viewMode: ListViewMode) => void;
    readonly supportsSettingsStorage: boolean;
    readonly settingStorageKey?: string;
    private readonly settingsStore?;
    private readonly viewModeStorageKey?;
    private readonly filterSettingsStorageKey?;
    private readonly sortingStorageKey?;
    constructor(shape: ListShape<T>);
    get isFiltered(): boolean;
    get visibleSorting(): Sorting<T>[];
    static useNew<T>(shape: ListShape<T>): List<T>;
    storeFilterDefaultSettings(): void;
    getStoredFilterDefaultSettings(): Record<string, string[]> | undefined;
    getStoredViewModeDefaultSetting(): "table" | "list" | "tiles" | undefined;
    storeSortingSettings(sorting: Sorting<T>): void;
    getStoredSortingDefaultSetting(): {
        property: string | number;
        direction: "desc" | "asc";
    } | undefined;
    getSorting(id: string): Sorting<T>;
    clearSorting(): void;
    resetFilters(): void;
    clearFilters(): void;
    useIsEmpty(): boolean;
}
export default List;
//# sourceMappingURL=List.d.ts.map