import { FilterShape } from './filter/types';
import { ItemViewShape } from './item/ItemView';
import { default as List } from './List';
import { IncrementalLoaderShape } from './loading/types';
import { BatchesControllerShape } from './pagination/types';
import { SearchShape } from './search/types';
import { SortingShape } from './sorting/types';
import { TableShape } from './table/types';
import { ItemType } from '../../../lib/types/array';
import { MultipleSelection, SelectionBehavior } from '@react-types/shared';
import { DeepKeys, DeepValue } from '@tanstack/react-table';
import { ReactNode } from 'react';
export declare const customPropertyPrefix: "$";
export type CustomPropertyName = `${typeof customPropertyPrefix}${string}`;
export type PropertyName<T> = DeepKeys<T> | CustomPropertyName;
export type PropertyValue<T, TProp> = TProp extends CustomPropertyName ? T : DeepValue<T, TProp>;
export type PropertyValueRenderMethod<TMatcherValue> = (prop: NonNullable<ItemType<TMatcherValue>>) => ReactNode;
export type OnListChanged<T> = (list: List<T>) => void;
export interface ListSupportedComponentProps extends MultipleSelection {
    "aria-labelledby"?: string;
    "aria-label"?: string;
    selectionBehavior?: SelectionBehavior;
}
export interface ListShape<T> extends ListSupportedComponentProps {
    settingStorageKey?: string;
    loader?: IncrementalLoaderShape<T>;
    filters?: FilterShape<T, never, never>[];
    itemView?: ItemViewShape<T>;
    search?: SearchShape<T>;
    sorting?: SortingShape<T>[];
    batchesController?: BatchesControllerShape;
    table?: TableShape<T>;
    onAction?: ItemActionFn<T>;
    accordion?: boolean;
    getItemId?: GetItemId<T>;
    onChange?: OnListChanged<T>;
    defaultViewMode?: ListViewMode;
}
export type PropertyRecord<T, TValue> = Partial<Record<PropertyName<T>, TValue>>;
export type ListViewMode = "table" | "list" | "tiles";
export type ItemActionFn<T> = (data: T) => void;
export type GetItemId<T> = (data: T) => string;
//# sourceMappingURL=types.d.ts.map